var searchData=
[
  ['d',['d',['../structlpi.html#a411cab0868ee86526ec41e53d68e15ce',1,'lpi::d()'],['../structnnai.html#a680e2d98ab08ebed90cad737df5dab5d',1,'nnai::d()'],['../structnnpi.html#a4a873a1a84656baa4e02b592ad8b000c',1,'nnpi::d()']]],
  ['d1cp',['d1cp',['../hash_8c.html#af43f7b4f80b9b80817d0af549fcf59dc',1,'hash.c']]],
  ['d1eq',['d1eq',['../hash_8c.html#af2ba20b09381bf49178632e5a76bcb2c',1,'hash.c']]],
  ['d1hash',['d1hash',['../hash_8c.html#a2d7678985946bb5139fde73c4787e2db',1,'hash.c']]],
  ['d2cp',['d2cp',['../hash_8c.html#a8e0dfc2c7086de0f5490e18990402518',1,'hash.c']]],
  ['d2eq',['d2eq',['../hash_8c.html#ace832e4b52f71dd361b99d1332afde33',1,'hash.c']]],
  ['d2hash',['d2hash',['../hash_8c.html#a058db54396c9cc6ec5dad9f8d6cd27f1',1,'hash.c']]],
  ['d_5fname',['d_name',['../structdirent.html#a1450b4488b7067c7dc9d627b61fd4aa1',1,'dirent']]],
  ['darkred',['DarkRed',['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba556650aa9f007ea0239e66d3ddf26759',1,'plstream.h']]],
  ['data',['data',['../structht__bucket.html#a6eddd03a72cdb1e3ede43b1d746efabe',1,'ht_bucket::data()'],['../structdirent.html#a6ec995059bf4370c93292745f7da4b13',1,'dirent::data()'],['../structswig__lua__rawdata.html#acbba29d10dcd1b96ba3b8d255b777749',1,'swig_lua_rawdata::data()']]],
  ['data_5fdir',['DATA_DIR',['../plplot__config_8h.html#a48cc0a91e8f54c62f3341c21c8cc74e8',1,'plplot_config.h']]],
  ['db',['db',['../structPLStream.html#a5b485e23de946ddaae43b13a71d120a2',1,'PLStream']]],
  ['dbug_5fenter',['dbug_enter',['../tclMatrix_8c.html#a6654afec69a24f13f463c90e1c62def5',1,'dbug_enter():&#160;tclMatrix.c'],['../pldebug_8h.html#a6654afec69a24f13f463c90e1c62def5',1,'dbug_enter():&#160;pldebug.h']]],
  ['dcast',['dcast',['../structswig__type__info.html#a07df4bedf85be77b23756b531b60e0dd',1,'swig_type_info']]],
  ['debug',['debug',['../structPLStream.html#a5083e76d7de0c5588dcb018bc2a82a37',1,'PLStream::debug()'],['../pdfutils_8c.html#ac3e1795766a80ec63b157951b4b9a7d4',1,'debug():&#160;pdfutils.c'],['../namespacePlframe.html#aea18aacc2b02182d559394b7a0e9a278',1,'Plframe.debug()'],['../plcore_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plcore.c'],['../plctrl_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plctrl.c'],['../plmap_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plmap.c'],['../ps_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;ps.c'],['../tk_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tk.c'],['../tkwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tkwin.c'],['../wxwidgets__dev_8cpp.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;wxwidgets_dev.cpp'],['../xwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;xwin.c']]],
  ['debugx',['DEBUGx',['../plframe_8c.html#aa0e4d6a92f0c37ad99ae6f1053184ed5',1,'plframe.c']]],
  ['declare_5foctave_5fallocator',['DECLARE_OCTAVE_ALLOCATOR',['../classoctave__swig__ref.html#a72e925362835c43be262e4cfaf616dc1',1,'octave_swig_ref::DECLARE_OCTAVE_ALLOCATOR()'],['../classoctave__swig__packed.html#aa238bbb14ac6ff2139e300a78faa871b',1,'octave_swig_packed::DECLARE_OCTAVE_ALLOCATOR()']]],
  ['declare_5fov_5ftypeid_5ffunctions_5fand_5fdata',['DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA',['../classoctave__swig__ref.html#ab71cb80e748fd244ad22e1ca10173408',1,'octave_swig_ref::DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA()'],['../classoctave__swig__packed.html#ae34643b7178a4835df5f4e5af61dce9f',1,'octave_swig_packed::DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA()']]],
  ['decref',['decref',['../classoctave__swig__type.html#a448579e13a4df84a340166bcf8d66acb',1,'octave_swig_type']]],
  ['deepblue',['DeepBlue',['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba059f250df53b7e6ea4b8b11dd9543e61',1,'plstream.h']]],
  ['def_5fplframe_5fbg_5fcolor',['DEF_PLFRAME_BG_COLOR',['../plframe_8c.html#a93009e093b0641f30748d9d2c0e5b859',1,'DEF_PLFRAME_BG_COLOR():&#160;plframe.c'],['../plplotter_8c.html#a93009e093b0641f30748d9d2c0e5b859',1,'DEF_PLFRAME_BG_COLOR():&#160;plplotter.c']]],
  ['def_5fplframe_5fbg_5fmono',['DEF_PLFRAME_BG_MONO',['../plframe_8c.html#ab379accfc1c7b2624804962d6366b4d4',1,'DEF_PLFRAME_BG_MONO():&#160;plframe.c'],['../plplotter_8c.html#ab379accfc1c7b2624804962d6366b4d4',1,'DEF_PLFRAME_BG_MONO():&#160;plplotter.c']]],
  ['def_5fplframe_5fborder_5fwidth',['DEF_PLFRAME_BORDER_WIDTH',['../plframe_8c.html#a84c7f34f97c2af29fd709af39f690a9b',1,'DEF_PLFRAME_BORDER_WIDTH():&#160;plframe.c'],['../plplotter_8c.html#a84c7f34f97c2af29fd709af39f690a9b',1,'DEF_PLFRAME_BORDER_WIDTH():&#160;plplotter.c']]],
  ['def_5fplframe_5fcursor',['DEF_PLFRAME_CURSOR',['../plframe_8c.html#a3c490d20f947eb1cd37fccb0127dfbf2',1,'DEF_PLFRAME_CURSOR():&#160;plframe.c'],['../plplotter_8c.html#a3c490d20f947eb1cd37fccb0127dfbf2',1,'DEF_PLFRAME_CURSOR():&#160;plplotter.c']]],
  ['def_5fplframe_5fheight',['DEF_PLFRAME_HEIGHT',['../plframe_8c.html#a548d59e98ec1be9e47025ae0f024a250',1,'DEF_PLFRAME_HEIGHT():&#160;plframe.c'],['../plplotter_8c.html#a548d59e98ec1be9e47025ae0f024a250',1,'DEF_PLFRAME_HEIGHT():&#160;plplotter.c']]],
  ['def_5fplframe_5frelief',['DEF_PLFRAME_RELIEF',['../plframe_8c.html#a8a65a863211281c46148ca9d5c2283d4',1,'DEF_PLFRAME_RELIEF():&#160;plframe.c'],['../plplotter_8c.html#a8a65a863211281c46148ca9d5c2283d4',1,'DEF_PLFRAME_RELIEF():&#160;plplotter.c']]],
  ['def_5fplframe_5fwidth',['DEF_PLFRAME_WIDTH',['../plframe_8c.html#ad588f83f30259629e69aa7de88e5010f',1,'DEF_PLFRAME_WIDTH():&#160;plframe.c'],['../plplotter_8c.html#ad588f83f30259629e69aa7de88e5010f',1,'DEF_PLFRAME_WIDTH():&#160;plplotter.c']]],
  ['def_5fwidth',['DEF_WIDTH',['../ps_8h.html#a89b0328645e4220f756e2ae014338602',1,'ps.h']]],
  ['default_5fdpi',['DEFAULT_DPI',['../qt_8h.html#a794e0417bdd7ebdad81c59a929932761',1,'qt.h']]],
  ['defaultfamilylookup',['defaultFamilyLookup',['../cairo_8c.html#a736736436b0cd48c0634f4b6d24281dc',1,'cairo.c']]],
  ['define_5foctave_5fallocator',['DEFINE_OCTAVE_ALLOCATOR',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1c38bc0a81e9cac4e99cad1615434041',1,'DEFINE_OCTAVE_ALLOCATOR(octave_swig_ref):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a621d8272de7916252c4a0565a86c2b43',1,'DEFINE_OCTAVE_ALLOCATOR(octave_swig_packed):&#160;plplot_octaveOCTAVE_wrap.cxx']]],
  ['define_5fov_5ftypeid_5ffunctions_5fand_5fdata',['DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac4d8460f6574c9e8f5f170ef57c99814',1,'DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA(octave_swig_ref,&quot;swig_ref&quot;,&quot;swig_ref&quot;):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a4002b21652bb2b7c222e4a3968be9b27',1,'DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA(octave_swig_packed,&quot;swig_packed&quot;,&quot;swig_packed&quot;):&#160;plplot_octaveOCTAVE_wrap.cxx']]],
  ['defined_5ffunc',['defined_func',['../plplotjavacJAVA__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotjavacJAVA_wrap.c'],['../plplotluacLUA__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['defines_2eh',['defines.h',['../defines_8h.html',1,'']]],
  ['defun_5fdld',['DEFUN_DLD',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac13932b327fb71daa08748c18951c3f9',1,'DEFUN_DLD(subclass, args, nargout, subclass_usage):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abbf0ebabef8311f62e7fae987a70b0fd',1,'DEFUN_DLD(swig_type, args, nargout, swig_type_usage):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a1088cd965f29ad14aca570370afb8fd7',1,'DEFUN_DLD(swig_typequery, args, nargout, swig_typequery_usage):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a41e892f26c71c2d1d444a693d46adcd7',1,'DEFUN_DLD(swig_this, args, nargout, swig_this_usage):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#af603dd8b1bc7c35c0f7d994edb96961f',1,'DEFUN_DLD(SWIG_name, args, nargout, SWIG_name_usage):&#160;plplot_octaveOCTAVE_wrap.cxx']]],
  ['deg_5fto_5frad',['DEG_TO_RAD',['../plarc_8c.html#a8ed7b6a1f199b6d2af90e642918cf271',1,'plarc.c']]],
  ['del',['del',['../structpattern.html#ac397895cd856f8cd427aced26ecabe64',1,'pattern']]],
  ['delargs',['delargs',['../structSwigPyClientData.html#a9cb4b9b02743d09dbe216f304e2b7df0',1,'SwigPyClientData']]],
  ['delaunay',['delaunay',['../structdelaunay.html',1,'delaunay'],['../nn_8h.html#a79d7f711a971d206b6807d6c1d1c1dc2',1,'delaunay():&#160;nn.h']]],
  ['delaunay_2ec',['delaunay.c',['../delaunay_8c.html',1,'']]],
  ['delaunay_2eh',['delaunay.h',['../delaunay_8h.html',1,'']]],
  ['delaunay_5fbuild',['delaunay_build',['../delaunay_8c.html#a9aae2bef9055892a7d9b0a73f1f8dc9c',1,'delaunay_build(int np, point points[], int ns, int segments[], int nh, double holes[]):&#160;delaunay.c'],['../nn_8h.html#a9aae2bef9055892a7d9b0a73f1f8dc9c',1,'delaunay_build(int np, point points[], int ns, int segments[], int nh, double holes[]):&#160;delaunay.c']]],
  ['delaunay_5fcircles_5ffind',['delaunay_circles_find',['../delaunay_8c.html#ab4038f72c5f4964715e533b24f8c9d2c',1,'delaunay_circles_find(delaunay *d, point *p, int *n, int **out):&#160;delaunay.c'],['../nnpi_8c.html#ab4038f72c5f4964715e533b24f8c9d2c',1,'delaunay_circles_find(delaunay *d, point *p, int *n, int **out):&#160;delaunay.c']]],
  ['delaunay_5fdestroy',['delaunay_destroy',['../delaunay_8c.html#a9385b99c0c93a5bb3cd9432b42ccb464',1,'delaunay_destroy(delaunay *d):&#160;delaunay.c'],['../nn_8h.html#a9385b99c0c93a5bb3cd9432b42ccb464',1,'delaunay_destroy(delaunay *d):&#160;delaunay.c']]],
  ['delaunay_5fxytoi',['delaunay_xytoi',['../delaunay_8c.html#a74337be0f7cc8fa5de9c5642037519c0',1,'delaunay_xytoi(delaunay *d, point *p, int id):&#160;delaunay.c'],['../lpi_8c.html#ac85731ad69839b9afb78272dae4a71d7',1,'delaunay_xytoi(delaunay *d, point *p, int seed):&#160;delaunay.c'],['../nnpi_8c.html#ac85731ad69839b9afb78272dae4a71d7',1,'delaunay_xytoi(delaunay *d, point *p, int seed):&#160;delaunay.c']]],
  ['delete',['delete',['../classplplot_1_1core_1_1PLGraphicsIn.html#a514cff07dbad695a8015934d887b77ce',1,'plplot::core::PLGraphicsIn']]],
  ['delete_5fplgraphicsin',['delete_PLGraphicsIn',['../classplplot_1_1core_1_1plplotjavacJNI.html#a1d7be0b0c2e45eb328af3a0724d8a2b8',1,'plplot::core::plplotjavacJNI']]],
  ['delete_5fplplotqt_5fsmoke',['delete_plplotqt_Smoke',['../plplotqt__smoke_8h.html#a61982820f42770dd268a2f1a8e09773e',1,'plplotqt_smoke.h']]],
  ['deletedata',['deleteData',['../structCommand.html#af5085ae0b6dca11a1b532731b2f54d7b',1,'Command']]],
  ['deletematrixcmd',['DeleteMatrixCmd',['../tclMatrix_8c.html#a847ca9aa013a7b23327afa8e513d39e5',1,'tclMatrix.c']]],
  ['deletematrixvar',['DeleteMatrixVar',['../tclMatrix_8c.html#a2627854222628cfcceffed0c995945e5',1,'DeleteMatrixVar(ClientData clientData, Tcl_Interp *interp, char *name1, char *name2, int flags):&#160;tclMatrix.c'],['../tclMatrix_8c.html#a7d4589c349b0241f669b74d702cca383',1,'DeleteMatrixVar(ClientData clientData, Tcl_Interp *PL_UNUSED(interp), char *PL_UNUSED(name1), char *PL_UNUSED(name2), int PL_UNUSED(flags)):&#160;tclMatrix.c']]],
  ['deleteproc',['deleteProc',['../structCommand.html#a8a2efb8447e4e31c6272bd7a53aa4b99',1,'Command']]],
  ['delta',['delta',['../structPLStream.html#aab6220efc877149ddaad3b45ea6cc9f7',1,'PLStream']]],
  ['deltat_2dgen_2ec',['deltaT-gen.c',['../deltaT-gen_8c.html',1,'']]],
  ['deltat_2eh',['deltaT.h',['../deltaT_8h.html',1,'']]],
  ['deltat_5ftest_2ec',['deltaT_test.c',['../deltaT__test_8c.html',1,'']]],
  ['depth',['depth',['../structTkwDisplay.html#a9426efee240bc4a860ee9331a1b2c537',1,'TkwDisplay::depth()'],['../structXwDisplay.html#a56193de1c93773eafd82499cd1b00717',1,'XwDisplay::depth()']]],
  ['desc',['desc',['../structcdImageStruct.html#a0e1ec004c6a0169c15ae3e029db44a86',1,'cdImageStruct::desc()'],['../structplplot_1_1__N1.html#af0534204dc57ea02028dbd2b9060e591',1,'plplot::_N1::desc()'],['../structPLOptionTable.html#a911b32327a6078131c7810248c0f02cc',1,'PLOptionTable::desc()']]],
  ['destroy',['destroy',['../structSwigPyClientData.html#a1c4e62712f23db599e85e24e14818d59',1,'SwigPyClientData']]],
  ['destroyed',['destroyed',['../structoctave__swig__type_1_1cpp__ptr.html#aa26dc33d9fabfdafd2ff3fb988c4a21b',1,'octave_swig_type::cpp_ptr']]],
  ['destroyplframe',['DestroyPlFrame',['../plframe_8c.html#a9e40812ac6b589fcc9eb6aae31d8235e',1,'plframe.c']]],
  ['destroyplplotter',['DestroyPlPlotter',['../plplotter_8c.html#a5e501919508d1aabed0725d563446623',1,'plplotter.c']]],
  ['destroyrband',['DestroyRband',['../plframe_8c.html#a988fd8384d5028d90d8b0149ab2a02f7',1,'DestroyRband(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#ab489dfabbb208eed8304595e09b71b73',1,'DestroyRband(PlPlotter *):&#160;plplotter.c']]],
  ['destroyxhairs',['DestroyXhairs',['../plframe_8c.html#a6e279cc9a9c417879fb220ac7d4d81d4',1,'DestroyXhairs(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#a6a4925ce3cc48bdde85bd7032a7c76b0',1,'DestroyXhairs(PlPlotter *):&#160;plplotter.c']]],
  ['destructor',['destructor',['../structswig__lua__class.html#ae7029d37913cf77df8f5c473c5cb43fe',1,'swig_lua_class::destructor()'],['../structswig__octave__class.html#a5e1ac4d7d832f631bc2001bfceeb374b',1,'swig_octave_class::destructor()']]],
  ['dev',['dev',['../structPLStream.html#abf8a6d71f35aeb854e3c75f5ed4f7679',1,'PLStream']]],
  ['dev_5f2005_5fheader',['dev_2005_header',['../plmetafile_8c.html#a355ad03ff95e155e9ef4654d7e15bb65',1,'plmetafile.c']]],
  ['dev_5farc',['dev_arc',['../structPLStream.html#a263a03b7f7481ecf73b47b50821d3006',1,'PLStream']]],
  ['dev_5fclear',['dev_clear',['../structPLStream.html#a5ffd0f763c8d12a0912ebc4355377329',1,'PLStream']]],
  ['dev_5fcompression',['dev_compression',['../structPLStream.html#a0b1b2bd10b03c184910e90aac79dddce',1,'PLStream']]],
  ['dev_5fdash',['dev_dash',['../structPLStream.html#a537ff4fef08a7f0978ac8f285739b54d',1,'PLStream']]],
  ['dev_5fdata',['dev_data',['../structPLStream.html#a64a27bd343528519bc7b9172ac9ae43b',1,'PLStream']]],
  ['dev_5fdi',['dev_di',['../structPLStream.html#ae84e24623a23d971c07e914557276808',1,'PLStream']]],
  ['dev_5fentry',['dev_entry',['../structdev__entry.html',1,'']]],
  ['dev_5feofill',['dev_eofill',['../structPLStream.html#ae43fbab5ba68a7c71f4cf5385178b2ff',1,'PLStream']]],
  ['dev_5ffastimg',['dev_fastimg',['../structPLStream.html#a7055c5f16dfa3de7f6c70fe69f846360',1,'PLStream']]],
  ['dev_5ffile_5fapp',['dev_file_app',['../structdev__entry.html#a1b3998791678ca6836eee87972dbd1a9',1,'dev_entry']]],
  ['dev_5ffill0',['dev_fill0',['../structPLStream.html#a36447d5d3f5bc8e6859c0b39308e4d6a',1,'PLStream']]],
  ['dev_5ffill1',['dev_fill1',['../structPLStream.html#acb765112b653f0c3bf7e9fd716d2daed',1,'PLStream']]],
  ['dev_5fflush',['dev_flush',['../structPLStream.html#ad906fcb4939128aac6738460716b28ac',1,'PLStream']]],
  ['dev_5fgradient',['dev_gradient',['../structPLStream.html#a753dd576c21893565997c66aa8d20b29',1,'PLStream']]],
  ['dev_5fhrshsym',['dev_hrshsym',['../structPLStream.html#a3d7a7ea09e1f39e922122ab6a8837f71',1,'PLStream']]],
  ['dev_5finitialized',['dev_initialized',['../structPLStream.html#a8c7933270949485ebbfe541d7bf45a06',1,'PLStream']]],
  ['dev_5fix',['dev_ix',['../structPLStream.html#a980c6538d17d90c388a88453546fc663',1,'PLStream']]],
  ['dev_5fiy',['dev_iy',['../structPLStream.html#a95520c10ded8c43651b5757cb7ca15c0',1,'PLStream']]],
  ['dev_5fmem_5falpha',['dev_mem_alpha',['../structPLStream.html#ab992021872cb743f34265ca2bd9388eb',1,'PLStream']]],
  ['dev_5fmenu_5flong',['dev_menu_long',['../structdev__entry.html#a47d1514de9a4d8519c0ee45bc6e62193',1,'dev_entry']]],
  ['dev_5fmenu_5fshort',['dev_menu_short',['../structdev__entry.html#a8504d919ebc6d33e0401f09721a5e056',1,'dev_entry']]],
  ['dev_5fminor',['dev_minor',['../structPLStream.html#a8577d7d860e6d7cc45f33c28c06263c0',1,'PLStream']]],
  ['dev_5fmodeset',['dev_modeset',['../structPLStream.html#a4b68f6f1f7a47daa793141fbbea35470',1,'PLStream']]],
  ['dev_5fname',['dev_name',['../structdev__entry.html#ab6060419382f71a0f13e9df4534dcd1d',1,'dev_entry']]],
  ['dev_5fnpts',['dev_npts',['../structPLStream.html#a47b274adf40a432cf4e95b4a54672199',1,'PLStream']]],
  ['dev_5fnptsx',['dev_nptsX',['../structPLStream.html#a766da98c5dceb23816632208aa2696b0',1,'PLStream']]],
  ['dev_5fnptsy',['dev_nptsY',['../structPLStream.html#ae2a1837b834853342917152d85a57c41',1,'PLStream']]],
  ['dev_5fswin',['dev_swin',['../structPLStream.html#ab85067bdc3a57afc4a2d3232eebf3b82',1,'PLStream']]],
  ['dev_5ftext',['dev_text',['../structPLStream.html#aa29bb1690b4fe47184b675881d98c272',1,'PLStream']]],
  ['dev_5funicode',['dev_unicode',['../structPLStream.html#a7ab92afcd83164c2633aa13f6056ef46',1,'PLStream']]],
  ['dev_5fx',['dev_x',['../structPLStream.html#a6566af9cc819e25fbbf1cef193ef6696',1,'PLStream']]],
  ['dev_5fxor',['dev_xor',['../structPLStream.html#a88688e6248b7dbdcbcc637b50ff62ec7',1,'PLStream']]],
  ['dev_5fy',['dev_y',['../structPLStream.html#a5442ed8975069a3962d3303fee4dcc2e',1,'PLStream']]],
  ['dev_5fz',['dev_z',['../structPLStream.html#a9c5fe11361bfc214207b1bf769199780',1,'PLStream']]],
  ['dev_5fzmax',['dev_zmax',['../structPLStream.html#aa1ab99774297abc47e0ae0a29b1c62fd',1,'PLStream']]],
  ['dev_5fzmin',['dev_zmin',['../structPLStream.html#a6b267f89557ceef8790911bbb9062bb7',1,'PLStream']]],
  ['devdesc',['devDesc',['../structPlFrame.html#a409578178dbf1cd9bbdf2ce4279503c8',1,'PlFrame::devDesc()'],['../structPlPlotter.html#aaea02031eb53d6fa673b96f19a626a3c',1,'PlPlotter::devDesc()']]],
  ['device',['device',['../structPLStream.html#aba76488f65f93041f7448fee09966b49',1,'PLStream']]],
  ['device_5fheader',['device_header',['../struct__plm__version.html#a4c0e4696f49c6ea945f336f1906b3965',1,'_plm_version']]],
  ['devicechangedpage',['DeviceChangedPage',['../classMasterHandler.html#a116d7f4335e46e6e281fa546991983c9',1,'MasterHandler']]],
  ['deviceclosed',['DeviceClosed',['../classMasterHandler.html#a7777a99d4053d69e61bb2134ad730fbe',1,'MasterHandler']]],
  ['devname',['devName',['../structPlFrame.html#a6bd51c8ea7742c10c24bf57f19a37583',1,'PlFrame::devName()'],['../structPlPlotter.html#a91a6a822d164ae7622b16657567dc372',1,'PlPlotter::devName()'],['../structPLStream.html#aab9c4166d130ca8e402b0b1c5e2539fe',1,'PLStream::DevName()']]],
  ['diclpxma',['diclpxma',['../structPLStream.html#acc943d43125d39d5abdc7b66a53944a9',1,'PLStream']]],
  ['diclpxmi',['diclpxmi',['../structPLStream.html#aedabf7549e134fb86674e4456e3b3313',1,'PLStream']]],
  ['diclpyma',['diclpyma',['../structPLStream.html#a97be1e95c2579b1fc3ed24da73601574',1,'PLStream']]],
  ['diclpymi',['diclpymi',['../structPLStream.html#a0d4efbdb77bab033d72bce77e20c8d15',1,'PLStream']]],
  ['did2pc',['did2pc',['../classplstream.html#a391ce788e59848110b661569d4b1e2c4',1,'plstream']]],
  ['didtests',['didTests',['../aqt_8c.html#a3403bf52b8edb6daa7bfab9a8b034eb2',1,'aqt.c']]],
  ['didxax',['didxax',['../structPLStream.html#ab3ab79d4152a296f7c4f6c091cb77850',1,'PLStream']]],
  ['didxb',['didxb',['../structPLStream.html#acee55fef7a78d2e7da7eec5ab106d29f',1,'PLStream']]],
  ['didyay',['didyay',['../structPLStream.html#a308d6a478bf546f5216399da614540f9',1,'PLStream']]],
  ['didyb',['didyb',['../structPLStream.html#a3f01563d90fa5c2c07a43d03e47e2db5',1,'PLStream']]],
  ['difilt',['difilt',['../structPLStream.html#ac22c7ab738732908f042c0f7f631b505',1,'PLStream::difilt()'],['../plcore_8c.html#a663c143ac825caaef262f7ca77b3c019',1,'difilt(PLINT *xsc, PLINT *ysc, PLINT npts, PLINT *clpxmi, PLINT *clpxma, PLINT *clpymi, PLINT *clpyma):&#160;plcore.c'],['../plplotP_8h.html#aeb14106a80979de5e9f0db61b38bbc11',1,'difilt(PLINT *, PLINT *, PLINT, PLINT *, PLINT *, PLINT *, PLINT *):&#160;plcore.c']]],
  ['difilt_5fclip',['difilt_clip',['../plcore_8c.html#a2e6bd1707a0ea6e38454e364c420eb5e',1,'difilt_clip(PLINT *x_coords, PLINT *y_coords):&#160;plcore.c'],['../plplotP_8h.html#a123456aef2077b98710c1945cc423716',1,'difilt_clip(PLINT *, PLINT *):&#160;plcore.c']]],
  ['digmax_5fdef',['DIGMAX_DEF',['../pldtik_8c.html#a2dc186368b713380d9e5fdcc390ee68e',1,'pldtik.c']]],
  ['dim',['dim',['../structtclMatrix.html#a6541392bf8e6ecb9d974e9dda856fa95',1,'tclMatrix']]],
  ['dims',['dims',['../classoctave__swig__type.html#a87a91c6e707e04784b99abe6b42cebd3',1,'octave_swig_type::dims()'],['../classoctave__swig__ref.html#ab3109a3c6e62a02440ced99e82bc481a',1,'octave_swig_ref::dims()']]],
  ['dimxax',['dimxax',['../structPLStream.html#ae8d1d27f3d9fc0282c0f0b5b3f233b42',1,'PLStream']]],
  ['dimxb',['dimxb',['../structPLStream.html#a20f7c2bf90e325b365cecd8d2b402847',1,'PLStream']]],
  ['dimxmax',['dimxmax',['../structPLStream.html#a393f3edb7c450ed1d700620bd3c58def',1,'PLStream']]],
  ['dimxmin',['dimxmin',['../structPLStream.html#abbf615b9443c409fd54f64d7a08d11ab',1,'PLStream']]],
  ['dimxpmm',['dimxpmm',['../structPLStream.html#a70512d186177200b25305e4d8613ebe9',1,'PLStream']]],
  ['dimyay',['dimyay',['../structPLStream.html#aaec9ca24b4dc06ac9b0b2fa2ac7dbd8d',1,'PLStream']]],
  ['dimyb',['dimyb',['../structPLStream.html#a74e66a6f996cbe9c004e9845daa94bba',1,'PLStream']]],
  ['dimymax',['dimymax',['../structPLStream.html#ae38a604c5b068a4b46435f2271fe5ea2',1,'PLStream']]],
  ['dimymin',['dimymin',['../structPLStream.html#a64abb742041bd2af0f4c4fb83602b03d',1,'PLStream']]],
  ['dimypmm',['dimypmm',['../structPLStream.html#a815964bc46df8351faefc688044709ed',1,'PLStream']]],
  ['diorot',['diorot',['../structPLStream.html#aff69cf352e07ab556f37a26d19a368fb',1,'PLStream']]],
  ['dioxax',['dioxax',['../structPLStream.html#a001400d3e49aad07d1c89d414b200673',1,'PLStream']]],
  ['dioxay',['dioxay',['../structPLStream.html#a179d0c392cf7a6684e54cb632b6ea225',1,'PLStream']]],
  ['dioxb',['dioxb',['../structPLStream.html#a59ccd7403a647195e073b5764143ff49',1,'PLStream']]],
  ['dioyax',['dioyax',['../structPLStream.html#a3f050b44ba82213a3dc63352ef328770',1,'PLStream']]],
  ['dioyay',['dioyay',['../structPLStream.html#ad05baefb79b865c1324f07e035ecd07d',1,'PLStream']]],
  ['dioyb',['dioyb',['../structPLStream.html#ab459504b6e9f6bb01e8a4f20dafb1a3b',1,'PLStream']]],
  ['dip2dc',['dip2dc',['../classplstream.html#a97f3fef8272ba076824a93fd038f9b92',1,'plstream']]],
  ['dipxax',['dipxax',['../structPLStream.html#a2cecc30bd1ca0277efc230aa1d4c7472',1,'PLStream']]],
  ['dipxb',['dipxb',['../structPLStream.html#a13ef64a5b452b7d4d332379fbdf3ea10',1,'PLStream']]],
  ['dipxmax',['dipxmax',['../structPLStream.html#a4b10cf67465134426a6e0315cda0b5c9',1,'PLStream']]],
  ['dipxmin',['dipxmin',['../structPLStream.html#a99afd44759ce4c50812930c4114379f0',1,'PLStream']]],
  ['dipyay',['dipyay',['../structPLStream.html#afd95befa6c0a9a9793dae9bcb8f7d6fb',1,'PLStream']]],
  ['dipyb',['dipyb',['../structPLStream.html#a475ed8fb0364fba619527d49e0bcd1d8',1,'PLStream']]],
  ['dipymax',['dipymax',['../structPLStream.html#a04323978cc4239d9dc14fc046242af7e',1,'PLStream']]],
  ['dipymin',['dipymin',['../structPLStream.html#aa8af982530bc17c9ff924805c3c01aad',1,'PLStream']]],
  ['dir',['DIR',['../structDIR.html',1,'DIR'],['../dirent__msvc_8h.html#acd3a9d173749674d17dc5a5618f5e97a',1,'DIR():&#160;dirent_msvc.h']]],
  ['director',['director',['../structswig__octave__class.html#af6c5e0b035923e4489939936e82fa15c',1,'swig_octave_class']]],
  ['dirent',['dirent',['../structdirent.html',1,'dirent'],['../plcore_8c.html#a89957e9be80ef12a50eb4eca72ecd888',1,'dirent():&#160;plcore.c'],['../dirent__msvc_8h.html#a789e4aa152d69b1205ea69ddb159c5b2',1,'dirent():&#160;dirent_msvc.h']]],
  ['dirent_5fmsvc_2eh',['dirent_msvc.h',['../dirent__msvc_8h.html',1,'']]],
  ['dispatch_5fbinary_5fop',['dispatch_binary_op',['../classoctave__swig__type.html#ab31d09df807b8efc728b45c9a39a0dc4',1,'octave_swig_type::dispatch_binary_op(const std::string &amp;symbol, const octave_base_value &amp;rhs, octave_value &amp;ret)'],['../classoctave__swig__type.html#a0981e27edd65dcc30f62459811aeef52',1,'octave_swig_type::dispatch_binary_op(const octave_base_value &amp;lhs, const octave_base_value &amp;rhs, const char *op_name)']]],
  ['dispatch_5fglobal_5fop',['dispatch_global_op',['../classoctave__swig__type.html#a7e7e9beada3d3a7449bf409f5f13ad9b',1,'octave_swig_type']]],
  ['dispatch_5findex_5fop',['dispatch_index_op',['../classoctave__swig__type.html#a23ef7c4889f253e702997f69cb75cf54',1,'octave_swig_type']]],
  ['dispatch_5ftable',['dispatch_table',['../structPLStream.html#a887a3e2a4b6fa529050419fddea30a77',1,'PLStream::dispatch_table()'],['../plcore_8h.html#a57e441fc18d6c70aa946cb3f31363099',1,'dispatch_table():&#160;plcore.h']]],
  ['dispatch_5funary_5fop',['dispatch_unary_op',['../classoctave__swig__type.html#a13b386a640ccc92d18d45fadc47bf4c6',1,'octave_swig_type::dispatch_unary_op(const std::string &amp;symbol, octave_value &amp;ret)'],['../classoctave__swig__type.html#a0f0b3859423b6abce8870beaeab912c2',1,'octave_swig_type::dispatch_unary_op(const octave_base_value &amp;x, const char *op_name)']]],
  ['display',['display',['../structPlFrame.html#aade49f122a5252b45ab7f0a54824314c',1,'PlFrame::display()'],['../structPlPlotter.html#aba63a469923ac91734ef6521bf3a96da',1,'PlPlotter::display()'],['../structTkwDisplay.html#a13d5ba6d124870de4d2c9cb56d9fe27d',1,'TkwDisplay::display()'],['../structXwDisplay.html#aed2b77a9ad5f7acdeb35637df3bdf591',1,'XwDisplay::display()'],['../tkMain_8c.html#ac673895cdd4a06409b42c362bc4ff0d2',1,'display():&#160;tkMain.c']]],
  ['displayname',['displayName',['../structTkwDisplay.html#a1779b68c9b97e7be0116c5640f81dca7',1,'TkwDisplay::displayName()'],['../structXwDisplay.html#ae540a35000de9cbebd7c2ba40fb86ca8',1,'XwDisplay::displayName()']]],
  ['displayplframe',['DisplayPlFrame',['../plframe_8c.html#a2423e92b737132cac49fb7838ecafba8',1,'plframe.c']]],
  ['displayplplotter',['DisplayPlPlotter',['../plplotter_8c.html#ac5b333b26331ce8525a2c4f1da1906f7',1,'plplotter.c']]],
  ['disptab_2eh',['disptab.h',['../disptab_8h.html',1,'']]],
  ['dist',['dist',['../structpt.html#a1c68de66b27b10580e7305bade7cd541',1,'pt']]],
  ['dist1',['dist1',['../plgridd_8c.html#a3e5cf930566629707488b64c1d404559',1,'plgridd.c']]],
  ['dist2',['dist2',['../plgridd_8c.html#a427e9eaadf932ecdffbf94de43b0d8d1',1,'plgridd.c']]],
  ['distance',['distance',['../csa_8c.html#a35d71de6ce16c9812718704541edc013',1,'csa.c']]],
  ['div',['div',['../structplf2ops__t.html#adee8c7c790b5b49672909c53f505a5d4',1,'plf2ops_t']]],
  ['do_5fct_5fcallback',['do_ct_callback',['../plplotcmodulePYTHON__wrap_8c.html#aa55de72b3611b0c8da14b06623b31d00',1,'plplotcmodulePYTHON_wrap.c']]],
  ['do_5ff2eval_5fcallback',['do_f2eval_callback',['../plplotcmodulePYTHON__wrap_8c.html#a186e3ee0d5d1fd3e9dcc77c8946d9607',1,'plplotcmodulePYTHON_wrap.c']]],
  ['do_5flabel_5fcallback',['do_label_callback',['../plplotcmodulePYTHON__wrap_8c.html#a5b0321ad235146d11e01257ddf5783e2',1,'plplotcmodulePYTHON_wrap.c']]],
  ['do_5fmapform_5fcallback',['do_mapform_callback',['../plplotcmodulePYTHON__wrap_8c.html#a2ad7669c1293909aafb1a4539ae41f4e',1,'plplotcmodulePYTHON_wrap.c']]],
  ['do_5fpltr_5fcallback',['do_pltr_callback',['../plplotcmodulePYTHON__wrap_8c.html#ad26774534ac3b87f0895b44638d77ace',1,'plplotcmodulePYTHON_wrap.c']]],
  ['doc',['doc',['../structswig__octave__member.html#a9d331d2028fa0141e9fb9824dfe48b9b',1,'swig_octave_member']]],
  ['domxma',['domxma',['../structPLStream.html#a4c6dedc71895250e9ca0d1c06ff8332d',1,'PLStream']]],
  ['domxmi',['domxmi',['../structPLStream.html#ac067cc75f47a42d588dc74194e0e0bc7',1,'PLStream']]],
  ['domyma',['domyma',['../structPLStream.html#a1a4d3ea4f87b7421f8e74f58c98ea866',1,'PLStream']]],
  ['domymi',['domymi',['../structPLStream.html#a5e0d0b52d8a39bceaca339e1d6f1396e',1,'PLStream']]],
  ['double_5fbuffer',['double_buffer',['../structPlPlotter.html#a2dc979e3e11b78f99df3329c82f21b78',1,'PlPlotter']]],
  ['downscale',['downscale',['../structPLCairo.html#a7210324a6b46a828bc114f3e605cc784',1,'PLCairo::downscale()'],['../classQtPLDriver.html#a05e234498832892294d6a0bed2fcae6e',1,'QtPLDriver::downscale()']]],
  ['dp',['dp',['../structPLStream.html#add8acf85b1d1d1800c8eb7df0535c400',1,'PLStream']]],
  ['dpi',['DPI',['../aqt_8c.html#a9dcb542bc9dbcae41fdb39a689798698',1,'DPI():&#160;aqt.c'],['../cairo_8c.html#a9dcb542bc9dbcae41fdb39a689798698',1,'DPI():&#160;cairo.c']]],
  ['dpmm',['DPMM',['../plplotP_8h.html#abaf07295f4b55cf9e4f5f6b7139505ed',1,'plplotP.h']]],
  ['draw',['Draw',['../plframe_8c.html#a79bb028b0b4631d8dff3b8300da148b3',1,'Draw(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a3b0e49f3e8d2003feba498b02e89d65b',1,'Draw(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a81d44beceea84a3a7260b379cdef39d5',1,'Draw(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#aae38b765818005f7fbce61912d6f5b3f',1,'Draw(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['draw_5fboundary',['draw_boundary',['../plshade_8c.html#ae994094a7ac1a50675b62634b5dc5abb',1,'plshade.c']]],
  ['draw_5fbox',['draw_box',['../pllegend_8c.html#af6b29766e98069e2fe20f311720da8a2',1,'pllegend.c']]],
  ['draw_5fcap',['draw_cap',['../pllegend_8c.html#ab4541b8525a876cb4b0a4a69dc1c009c',1,'pllegend.c']]],
  ['draw_5flabel',['draw_label',['../pllegend_8c.html#accb8ba6706a3e7d9b03bfbdacb83e197',1,'pllegend.c']]],
  ['draw_5flinex',['DRAW_LINEX',['../classplplot.html#a53c151ff9300048429b05568946f4b58',1,'plplot::DRAW_LINEX()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a78186e922b4c0587058b89df782d5ead',1,'plplot.core.plplotjavacConstants.DRAW_LINEX()'],['../plplot_8h.html#abc232a5d2bdcfe6d917d28b1d0113261',1,'DRAW_LINEX():&#160;plplot.h'],['../namespaceplplotc.html#a1468d03369594fe90e8eb5cc464a859b',1,'plplotc.DRAW_LINEX()']]],
  ['draw_5flinex_5fget',['DRAW_LINEX_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a4ae96306dae305abfe6b865484585b26',1,'plplot::core::plplotjavacJNI']]],
  ['draw_5flinexy',['DRAW_LINEXY',['../classplplot.html#ab4fc454297b7b4df3c1f73fe9dae4cbe',1,'plplot::DRAW_LINEXY()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6b221b57c0b722bcca7d18195666d5fb',1,'plplot.core.plplotjavacConstants.DRAW_LINEXY()'],['../plplot_8h.html#ab0c68fc37f1b7d44b612136a9447a26a',1,'DRAW_LINEXY():&#160;plplot.h'],['../namespaceplplotc.html#ac51a99e6a9f091db6f2996d97f675fd6',1,'plplotc.DRAW_LINEXY()']]],
  ['draw_5flinexy_5fget',['DRAW_LINEXY_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a2f52398f1317caa98e32eeb12d3b878c',1,'plplot::core::plplotjavacJNI']]],
  ['draw_5fliney',['DRAW_LINEY',['../classplplot.html#aa566c9a8b5967e071359585fbbe5975e',1,'plplot::DRAW_LINEY()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a57935553f9eed159d7071c06cdf27e18',1,'plplot.core.plplotjavacConstants.DRAW_LINEY()'],['../plplot_8h.html#a6b90cdc3b439f3c31a19c9b610732b96',1,'DRAW_LINEY():&#160;plplot.h'],['../namespaceplplotc.html#ae85623e8a7f98f87cf65876928d75951',1,'plplotc.DRAW_LINEY()']]],
  ['draw_5fliney_5fget',['DRAW_LINEY_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a55620e6b0397d1833e69d4fe877cef5c',1,'plplot::core::plplotjavacJNI']]],
  ['draw_5fsides',['DRAW_SIDES',['../classplplot.html#a498074676eb148d19d7465505e44ae2c',1,'plplot::DRAW_SIDES()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1045c9467abda926a1710b7103962e9b',1,'plplot.core.plplotjavacConstants.DRAW_SIDES()'],['../plplot_8h.html#a97f8c99c7977160450c93302222ff923',1,'DRAW_SIDES():&#160;plplot.h'],['../namespaceplplotc.html#a666c56f6d51ce51bd51c15bde0834f75',1,'plplotc.DRAW_SIDES()']]],
  ['draw_5fsides_5fget',['DRAW_SIDES_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#ae29a29a6dc31c02746e380652a402275',1,'plplot::core::plplotjavacJNI']]],
  ['drawarc',['drawArc',['../classQtPLDriver.html#a5cf646c1903e03bcb412c89f300dcbd7',1,'QtPLDriver']]],
  ['drawing',['DRAWING',['../plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55ba958d99ff23a05900a8e5cf1a56055098',1,'plcore.c']]],
  ['drawing_5frband',['drawing_rband',['../structPlFrame.html#adf4ddc0c44164d8a0d5bdfa3e0878aef',1,'PlFrame::drawing_rband()'],['../structPlPlotter.html#a153b99d69175b18f0691cc1d0d593c4e',1,'PlPlotter::drawing_rband()']]],
  ['drawing_5fxhairs',['drawing_xhairs',['../structPlFrame.html#a983f748494f81aecc7bd02ad139b168c',1,'PlFrame::drawing_xhairs()'],['../structPlPlotter.html#af10abb0cf0b1266ccdf1641e6551b2af',1,'PlPlotter::drawing_xhairs()'],['../structTkwDev.html#a3e454f604d96880ce717313096bc51c6',1,'TkwDev::drawing_xhairs()'],['../structXwDev.html#a9a6b2d42496aa00b41eac624b8b70101',1,'XwDev::drawing_xhairs()']]],
  ['drawingobjectschanger',['DrawingObjectsChanger',['../classDrawingObjectsChanger.html',1,'DrawingObjectsChanger'],['../classDrawingObjectsChanger.html#aaf5fe3bbb3ebbec3cb8ff0f0c358c044',1,'DrawingObjectsChanger::DrawingObjectsChanger()']]],
  ['drawline',['DrawLine',['../classwxPLDevice.html#a024a6ab0b2b388e6cf576f19eb570012',1,'wxPLDevice::DrawLine()'],['../classQtPLDriver.html#a38b4f012ad0e81163a19b305c0bf8406',1,'QtPLDriver::drawLine()']]],
  ['drawmap',['drawmap',['../plmap_8c.html#a94b2114d27fff7fb57a6ff0265214d29',1,'plmap.c']]],
  ['drawmapdata',['drawmapdata',['../plmap_8c.html#a6b5ddc18b28888ae7e6188e7a53a8416',1,'plmap.c']]],
  ['drawpolygon',['drawPolygon',['../classQtPLDriver.html#a9a8b786c8cbb7842e5afd1d0692c4748',1,'QtPLDriver']]],
  ['drawpolyline',['DrawPolyline',['../classwxPLDevice.html#a01db4914fcf1edabcc2e4bb0ccbe4771',1,'wxPLDevice::DrawPolyline()'],['../classQtPLDriver.html#a48608fec3c86975f597e2741877b9a3d',1,'QtPLDriver::drawPolyline()']]],
  ['drawrband',['DrawRband',['../plframe_8c.html#a15a2da7baf33ee3bcf95a3fa301a4a78',1,'DrawRband(PlFrame *, int, int):&#160;plframe.c'],['../plplotter_8c.html#a34e94728a8cbb3f868617819d2e21f93',1,'DrawRband(PlPlotter *, int, int):&#160;plplotter.c']]],
  ['drawtext',['drawText',['../classQtPLDriver.html#ac2fa93d479f3c737375f933d9eff4e32',1,'QtPLDriver']]],
  ['drawtextinpicture',['drawTextInPicture',['../classQtPLDriver.html#ab60f69a6b11708230670c807f4cc5b4d',1,'QtPLDriver']]],
  ['drawtextline',['DrawTextLine',['../classwxPLDevice.html#aed5eee301b35cddca3df03aed98831df',1,'wxPLDevice']]],
  ['drawtextsection',['DrawTextSection',['../classwxPLDevice.html#a3467fe2089747cce63432170380719d6',1,'wxPLDevice']]],
  ['drawxhairs',['DrawXhairs',['../plframe_8c.html#ad0fc44bf75ba9c49e410b8758ab2e5a7',1,'DrawXhairs(PlFrame *, int, int):&#160;plframe.c'],['../plplotter_8c.html#a88797198c2fdfdb31fedd9f8201dc27a',1,'DrawXhairs(PlPlotter *, int, int):&#160;plplotter.c']]],
  ['driver_5finterface',['DRIVER_INTERFACE',['../metadefs_8h.html#a69063a66eb5cc1673e7898be53e40bd5',1,'metadefs.h']]],
  ['drivers_2eh',['drivers.h',['../drivers_8h.html',1,'']]],
  ['drv_5fdir',['DRV_DIR',['../plplot__config_8h.html#a1aeab21c6fb43c1aa1c36717a7ad8855',1,'plplot_config.h']]],
  ['drv_5fflt',['DRV_FLT',['../plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06ca003e5f646837605b279c4a3e21a9e55d',1,'plplotP.h']]],
  ['drv_5fint',['DRV_INT',['../plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06caa346c93ff529b2e76f26fff7dcb37c92',1,'plplotP.h']]],
  ['drv_5fopt',['drv_opt',['../plargs_8c.html#ad42924d347ff680f9d8e7eb36415f079',1,'plargs.c']]],
  ['drv_5fstr',['DRV_STR',['../plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06cac8cb0d9ed936be241f5a8d60e42056c2',1,'plplotP.h']]],
  ['drvopt',['DrvOpt',['../structDrvOpt.html',1,'']]],
  ['drvoptcmd',['DrvOptCmd',['../structDrvOptCmd.html',1,'DrvOptCmd'],['../plargs_8c.html#a9f5d22d9bb9fd5fa8fa4c5e047003797',1,'DrvOptCmd():&#160;plargs.c']]],
  ['drvspec_5flen',['DRVSPEC_LEN',['../test-drv-info_8c.html#afbf160acae1f06ccb188f3c8cdf7f8d1',1,'test-drv-info.c']]],
  ['drvspec_5fsize',['DRVSPEC_SIZE',['../plcore_8c.html#aeccd9f754e3d81d10b32e0449323bafb',1,'plcore.c']]],
  ['dspline',['dspline',['../dspline_8c.html#aa0b641fe1a6891501cfd378a76514411',1,'dspline(double *x, double *y, int n, int if1, double cond1, int ifn, double condn, double *y2):&#160;dspline.c'],['../dspline_8h.html#aa0b641fe1a6891501cfd378a76514411',1,'dspline(double *x, double *y, int n, int if1, double cond1, int ifn, double condn, double *y2):&#160;dspline.c']]],
  ['dspline_2ec',['dspline.c',['../dspline_8c.html',1,'']]],
  ['dspline_2eh',['dspline.h',['../dspline_8h.html',1,'']]],
  ['dsplint',['dsplint',['../dsplint_8c.html#a6607655d3738a428ae5f8f2372e87271',1,'dsplint(double *xa, double *ya, double *y2a, int n, double x, double *y):&#160;dsplint.c'],['../dsplint_8h.html#a6607655d3738a428ae5f8f2372e87271',1,'dsplint(double *xa, double *ya, double *y2a, int n, double x, double *y):&#160;dsplint.c']]],
  ['dsplint_2ec',['dsplint.c',['../dsplint_8c.html',1,'']]],
  ['dsplint_2eh',['dsplint.h',['../dsplint_8h.html',1,'']]],
  ['dtor',['DTOR',['../plfill_8c.html#a06e28c801ea48dde51889eb3c4836c78',1,'plfill.c']]],
  ['dtr',['dtr',['../plwind_8c.html#a30b567fc9a9ac764ff7bfff0403b469f',1,'plwind.c']]],
  ['dum_5fuchar',['dum_uchar',['../plr_8c.html#ae41f387fd9b07755f1b68ea2b834786f',1,'plr.c']]],
  ['dum_5fushort',['dum_ushort',['../plr_8c.html#a7379e9a3346908d1d9c0eac320a065f4',1,'plr.c']]],
  ['dvalue',['dvalue',['../structswig__lua__const__info.html#ac50e848b2a6a628fa1eeb4924f608cee',1,'swig_lua_const_info::dvalue()'],['../structswig__const__info.html#a74e477f1dbf515bcb7e2ef07a1d34c35',1,'swig_const_info::dvalue()']]],
  ['dx',['dx',['../structplplot__graphics_1_1plgraphicsin.html#ac3f083e4645ed568195d759a57fb6816',1,'plplot_graphics::plgraphicsin::dx()'],['../structIMG__DT.html#a96c130e4360f7780f2d161c0a3f32108',1,'IMG_DT::dx()'],['../structplplot_1_1__N2.html#ac646480593d84982db2b8e860117d475',1,'plplot::_N2::dX()'],['../structPLGraphicsIn.html#ae15d582003fed123c0d48d422bffd144',1,'PLGraphicsIn::dX()'],['../namespacePlframe.html#a2def17e5a9cb1392e4f4fa30fd6de33e',1,'Plframe.dx()']]],
  ['dxma',['dxma',['../structplplot_1_1__N3.html#a5fa61330c619cd69264439d602c5efd2',1,'plplot::_N3::dxma()'],['../structPLWindow.html#aa7846632259bd8ddb2cf695b4112232a',1,'PLWindow::dxma()']]],
  ['dxmi',['dxmi',['../structplplot_1_1__N3.html#aefe9237accf83fb06db55ab6a10e7ee8',1,'plplot::_N3::dxmi()'],['../structPLWindow.html#afa3570309e945c264e79ba2a3a566fec',1,'PLWindow::dxmi()']]],
  ['dy',['dy',['../structplplot__graphics_1_1plgraphicsin.html#ad029a91a4f2d101ea0c7d428762eae5e',1,'plplot_graphics::plgraphicsin::dy()'],['../structIMG__DT.html#a18206f1e64d54e345fcde39d067e6ad7',1,'IMG_DT::dy()'],['../structplplot_1_1__N2.html#ae6c62648845e3d0ba49ea02faabc4127',1,'plplot::_N2::dY()'],['../structPLGraphicsIn.html#a90a08dfcb5e486ac4ce34507a6004c11',1,'PLGraphicsIn::dY()'],['../namespacePlframe.html#a392c52a1b0b0b952bb2a7fada883e13a',1,'Plframe.dy()']]],
  ['dyma',['dyma',['../structplplot_1_1__N3.html#a8c0d51fd26029f65910eb9473627381c',1,'plplot::_N3::dyma()'],['../structPLWindow.html#a4d0b980695e01367e50079521e61fc24',1,'PLWindow::dyma()']]],
  ['dymi',['dymi',['../structplplot_1_1__N3.html#af0e5799d84888b318e2995e04ea8d1a8',1,'plplot::_N3::dymi()'],['../structPLWindow.html#ac5a88aaabbd32564239f8a3f62f8892b',1,'PLWindow::dymi()']]]
];
